roc_auc Mean | roc_auc 95CI.LO | roc_auc 95CI.HI | model__max_features | model__n_estimators | preparation__non_numeric_pipeline__encoder_chooser__transformer
--- | --- | --- | --- | --- | ---
0.747 | 0.695 | 0.799 | sqrt | 50 | OneHotEncoder()
0.745 | 0.738 | 0.752 | sqrt | 50 | CustomOrdinalEncoder()
0.732 | 0.691 | 0.772 | 100 | 50 | OneHotEncoder()
0.726 | 0.699 | 0.752 | 100 | 50 | CustomOrdinalEncoder()
0.717 | 0.678 | 0.756 | sqrt | 10 | OneHotEncoder()
0.705 | 0.660 | 0.751 | sqrt | 10 | CustomOrdinalEncoder()
0.705 | 0.659 | 0.752 | 100 | 10 | OneHotEncoder()
0.701 | 0.673 | 0.729 | 100 | 10 | CustomOrdinalEncoder()